@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2021 Wacom. All rights reserved.
+""""
+Named Entity Linking
+"""
 
 __all__ = ['base', 'engine']
 
